package com.example.gallery.ui.albums

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.gallery.models.Album
import com.example.gallery.repository.GalleryRepository
import kotlinx.coroutines.launch

class AlbumsViewModel : ViewModel() {
    private val repository = GalleryRepository()

    private val _albums = MutableLiveData<List<Album>>()
    val albums: LiveData<List<Album>> = _albums

    private val _isLoading = MutableLiveData<Boolean>()
    val isLoading: LiveData<Boolean> = _isLoading

    private val _error = MutableLiveData<String?>()
    val error: LiveData<String?> = _error

    init {
        loadAlbums()
    }

    fun loadAlbums() {
        viewModelScope.launch {
            _isLoading.value = true
            _error.value = null

            repository.getAlbums().fold(
                onSuccess = { albumsList ->
                    _albums.value = albumsList
                    _isLoading.value = false
                },
                onFailure = { e ->
                    _error.value = e.message ?: "Неизвестная ошибка"
                    _isLoading.value = false
                }
            )
        }
    }

    fun refreshAlbums() {
        loadAlbums()
    }
}